@@ -242,11 +242,10 @@ class GoferHandler(HubAuthenticated, tornado.web.RequestHandler):
             user = self.get_current_user()
             log_info_csv("PRINT USER OBJ", course, section, assignment, str(user))
             if user is None:
-                user = {"name": os.getenv("TEST_USER")}
+                url_referer = self.request.headers.get("Referer")
+                user = {"name": url_referer.split("/")[4]}
                 using_test_user = True
             req_data = tornado.escape.json_decode(self.request.body)
-            ref_data = self.request.headers.get("Referer")
-            log_info_csv("GOT IT", course, section, assignment, str(ref_data))
             # in the future, assignment should be metadata in notebook
             if 'nb' in req_data:
                 notebook = req_data['nb']
@@ -265,7 +264,7 @@ class GoferHandler(HubAuthenticated, tornado.web.RequestHandler):
             if notebook is None or section is None or assignment is None:
                 raise GradeSubmissionException("Notebook does not have required metadata or maybe no notebook in post")
 
-            log_info_csv(user["name"], course, section, assignment, f"User logged in at {timestamp} -  TEST_USER: {using_test_user}")
+            log_info_csv(user["name"], course, section, assignment, f"User logged in at {timestamp} -  Using Referrer: {using_test_user}")
             # save notebook submission with user id and time stamp
             submission_file = f"{VOLUME_PATH}/submissions/{user['name']}_{section}_{assignment}_{timestamp}.ipynb"
             with open(submission_file, 'w', encoding="utf8") as outfile:
